# Add support for postinstall file and script:
class linux_postinstall(
  $install_packages     = undef,
  $upload_share         = undef,
  $upload_file          = undef,
  $upload_recursive     = false,
  $execute_file_command = undef,
  $yum_proxy            = undef,
) {

  $path = "${vardir}/staging:${vardir}/staging/${file}:${::path}"
  $vardir = $::puppet_vardir
  if $upload_share {
    $mod_path = $upload_share
  } else {
    $mod_path = 'puppet:///modules/linux_postinstall'
  }

  if $install_packages {
    $packages = split($install_packages, ',')

    package { $packages:
      ensure => present,
    }
  }

  if $upload_file {
    $staging = "${vardir}/staging"
    file { $staging:
      ensure => directory,
      mode   => 755,
    }

    file { "${staging}/${upload_file}":
      source  => "${mod_path}/${upload_file}",
      recurse => $upload_recursive,
      before  => Exec[postinstall],
    }

    if $upload_recursive {
      $cwd = "${staging}/${file}"
    } else {
      $cwd = $staging
    }
  }

  $exec_lck = "${vardir}/postinstall.lck"

  if $execute_file_command{
    exec { postinstall:
      command   => $execute_file_command,
      path      => $path,
      cwd       => $cwd,
      creates   => $exec_lck,
      logoutput => true,
    }

    file { $exec_lck:
      ensure  => file,
      require => Exec[postinstall],
    }
  }
  
  if $yum_proxy {
    if ($::osfamily == "Suse") {
      # For Suse, zypper is used for installing packages and uses proxy
      # settings from sysconfig. So we enable proxy for sysconfig
      file_line { "${yum_proxy}_proxy_enabled" :
        line   => "PROXY_ENABLED=\"yes\"",
        path   => "/etc/sysconfig/proxy",
        match  => "^PROXY_ENABLED=",
        before => Package[$packages],
      }
      file_line { "${yum_proxy}_http" :
        line   => "HTTP_PROXY=\"${yum_proxy}\"",
        path   => "/etc/sysconfig/proxy",
        match  => "^HTTP_PROXY",
        before => Package[$packages],
      }
      file_line { "${yum_proxy}_https" :
        line   => "HTTPS_PROXY=\"${yum_proxy}\"",
        path   => "/etc/sysconfig/proxy",
        match  => "^HTTPS_PROXY",
        before => Package[$packages],
      }
      file_line { "${yum_proxy}_ftp" :
        line   => "FTP_PROXY=\"${yum_proxy}\"",
        path   => "/etc/sysconfig/proxy",
        match  => "^FTP_PROXY",
        before => Package[$packages],
      }
    }
    else {
      file_line { yum_proxy :
        ensure => present,
        line   => "proxy=${yum_proxy}",
        path   => "/etc/yum.conf",
        before => Package[$packages],
      }
    }
  }
}
